#   ――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――
#   File: libomemo.spec
#   Copyright 🄯 2022, 2023, 2025 Van de Bugger.
#   SPDX-License-Identifier: FSFAP
#   ――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――

%vdb

%global         nam     omemo
%global         ver     0.8.1
%global         rel     0.vdb.3

Name:           lib%{nam}
Version:        %{ver}
Release:        %{rel}%{?dist}
Summary:        Implements OMEMO (XEP-0384 v0.3.0) in C

License:        MIT
URL:            https://github.com/gkdr/%{name}
Source0:        https://github.com/gkdr/%{name}/archive/refs/tags/v%{ver}.tar.gz#/%{name}-%{ver}.tar.gz

BuildRequires:  cmake >= 3.15 %{rem: --strip option required}
BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  pkgconfig(cmocka)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libgcrypt)
BuildRequires:  pkgconfig(mxml)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  vdb-rpm-macros

%package devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description
%{text -- \
    Input and output are XML strings, so it does not force you to use a certain XML lib. While the
    actual protocol functions do not depend on any kind of storage, it comes with a basic
    implementation in SQLite.

    It deals with device lists and bundles as well as encrypting the payload, but does not handle
    the double ratchet sessions for encrypting the key to the payload. However, you can use my axc
    lib for that and easily combine it with this one (or write all the libsignal client code
    yourself if that is better suited to your needs).
}

%description devel
Header files, pkgconfig file, and other development files of %{name}.

%prep
%autosetup

%build
%{cmake}
%{cmake_build}

%install
%{cmake_install}

%check
%{cmake_build} -- test

%files
            %{_libdir}/%{name}.so.*
%license    LICENSE

%files devel
%dir        %{_includedir}/%{name}/
            %{_includedir}/%{name}/*
            %{_libdir}/%{name}.so
            %{_libdir}/pkgconfig/%{name}.pc

%changelog

* Sat Mar 22 2025 Van de Bugger - 0.8.1-0.vdb.3
- vdb.lua is in dedicated package.

* Wed Mar  5 2025 Van de Bugger - 0.8.1-0.vdb.2
- F41 rebuild.

* Wed Jun 28 2023 Van de Bugger - 0.8.1-0.vdb.1
- v0.8.1
- libomemo is using cmake now

* Fri Mar 11 2022 Van de Bugger - 0.8.0-0.vdb.1
- Initial release
